import { __decorate, __param } from "tslib";
import { Container } from '@microsoft/fast-foundation';
import { RouterConfiguration } from '@microsoft/fast-router';
import { defaultLayout } from '../layouts';
import { Account } from './account/account';
import { Appearance } from './appearance/appearance';
import { NotFound } from './not-found/not-found';
import { Notifications } from './notifications/notifications';
// TODO: Update with the latest logic I have in Login
let MainRouterConfig = class MainRouterConfig extends RouterConfiguration {
    constructor(container) {
        super();
        this.container = container;
    }
    configure() {
        this.title = 'Settings';
        this.defaultLayout = defaultLayout;
        this.routes.map({ path: '', redirect: 'account' }, {
            path: 'account',
            element: Account,
            title: 'Account',
            name: 'account',
            settings: { foo: 'bar' },
        }, { path: 'appearance', element: Appearance, title: 'Appearance', name: 'appearance' }, {
            path: 'notifications',
            element: Notifications,
            title: 'Notifications',
            name: 'notifications',
        }, { path: 'not-found', element: NotFound, title: 'Not Found', name: 'not-found' });
        /**
         * Example of a FallbackRouteDefinition, could check session for login redirect
         */
        this.routes.fallback(() => ({ redirect: 'not-found' }));
        /**
         * Example of a NavigationContributor
         */
        this.contributors.push({
            navigate: (phase) => {
                const settings = phase.route.settings;
                /**
                 * If public route don't block
                 */
                if (settings && settings.public) {
                    return;
                }
                /**
                 * If logged in don't block
                 * if (auth.isLoggedIn) {
                 *     return;
                 * }
                 */
                /**
                 * Otherwise kick them out, something like:
                 * phase.cancel(() => {
                 *     // session.captureReturnUrl();
                 *     Route.name.replace(phase.router, 'login');
                 * });
                 */
            },
        });
    }
    construct(Type) {
        return this.container.get(Type);
    }
};
MainRouterConfig = __decorate([
    __param(0, Container)
], MainRouterConfig);
export { MainRouterConfig };
